<tr class="{$CYCLE,results_table_zebra,zebra_0,zebra_1}">
	<td><a href="{WEBSITE_URL*}" target="_blank" title="{WEBSITE_NAME*} {!LINK_NEW_WINDOW}">{WEBSITE_NAME*}</a></td>
	<td><abbr title="{!DAYS_AGO,{LAST_ACP_ACCESS_2*}}">{!HOURS_AGO,{LAST_ACP_ACCESS*}}</abbr></td>
	<td>{CMS_ACTIVE*}</td>
	<td>{VERSION*}</td>
	<td>{NOTE*}</td>
</tr>

