<h2>Feedback</h2>

<div>Please rate this tutorial:<br />{RATING}</div>

<p>Have a suggestion? Report an issue <a target="_blank" href="http://compo.sr/tracker/set_project.php?project_id=7" title="Report issue on tracker {!LINK_NEW_WINDOW}">on the tracker</a>.</p>
